# OAK Codebase Intelligence notify configuration for Codex

notify = ["{oak-cli-command}"{% for arg in notify_args %}, "{{ arg }}"{% endfor %}{% if notify_script_path %}, "{{ notify_script_path }}"{% endif %}]
